
.. image:: https://travis-ci.org/sonofeft/Tk_Nosy.svg?branch=master
    :target: https://travis-ci.org/sonofeft/Tk_Nosy

Tk_Nosy monitors project and unittest files and runs nosetests when they change.
================================================================================

The goal of Tk_Nosy is to encourage unit testing. This helps a developer use 
Test Driven Development (TDD) regardless of the editor or IDE being used.

Tk_Nosy will run nosetests with any python interpreter when any files
under development change.  

It can run any number of python interpreters concurrently such that, for example, 
python 2 and python 3 conventions can both be monitored at the same time.

In addition to conventional CPython, PYPY is also acceptable.

See the Code at: `<https://github.com/sonofeft/Tk_Nosy>`_

See the Docs at: `<http://tk-nosy.readthedocs.org/en/latest/>`_
